DROP TABLE PURCHASE;
DROP TABLE PRODUCT;
DROP TABLE CUSTOMER;
DROP TABLE SUPPLIER;
DROP TABLE STAFF;

CREATE TABLE CUSTOMER (
	CUSTOMER_ID number(10), 
	CUSTOMER_NAME varchar(20),
	EMAIL varchar(30),
	BANKACCOUNT_NO varchar(12),
	ADDRESS varchar(30),
	PRIMARY KEY(CUSTOMER_ID)
);

CREATE TABLE SUPPLIER(
	SUPPLIER_ID number(10),
	SUPPLIER_NAME varchar(20),
	EMAIL varchar(30),
	PHONE varchar(14),
	ADDRESS varchar(30),
	PRIMARY KEY(SUPPLIER_ID)
);

CREATE TABLE STAFF(
	STAFF_ID number(10),
	STAFF_NAME varchar(20),
	DESIGNATION varchar(20),
	EMAIL varchar(30),
	PHONE varchar(14), 
	ADDRESS varchar(30),
	PRIMARY KEY(STAFF_ID)
);

CREATE TABLE PRODUCT(
	PRODUCT_ID number(10),
	PRODUCT_NAME varchar(30),
	PRODUCT_TYPE varchar(10),
	PRODUCT_PRICE number(6),
	PRODUCT_DETAILS varchar(30),
	SUPPLIER_ID  number(10),
	PRIMARY KEY(PRODUCT_ID),
	FOREIGN KEY(SUPPLIER_ID) REFERENCES SUPPLIER(SUPPLIER_ID) ON DELETE CASCADE
);


CREATE TABLE PURCHASE(
	PURCHASE_NO number(10),
	CUSTOMER_ID number(10),
	PRODUCT_ID number(10),
	STAFF_ID number(10),
	QUANTITY number(4),
	TOTAL_PRICE number(6),
	DATE_PURCHASE varchar(10),
	PRIMARY KEY(PURCHASE_NO),
	FOREIGN KEY(CUSTOMER_ID) REFERENCES CUSTOMER(CUSTOMER_ID) ON DELETE CASCADE,
	FOREIGN KEY(PRODUCT_ID) REFERENCES PRODUCT(PRODUCT_ID) ON DELETE CASCADE,
	FOREIGN KEY(STAFF_ID) REFERENCES STAFF(STAFF_ID) ON DELETE CASCADE
);


INSERT INTO CUSTOMER VALUES(1000000001, 'MR. CUSTOMER_1', 'CUSTOMER_1@gmail.com', 'CI-0000001', 'Fulbarigate, Khulna');
INSERT INTO CUSTOMER VALUES(1000000002, 'MR. CUSTOMER_2', 'CUSTOMER_2@gmail.com', 'CI-0000002', 'Rupsha, Khulna');
INSERT INTO CUSTOMER VALUES(1000000003, 'MR. CUSTOMER_3', 'CUSTOMER_3@gmail.com', 'CI-0000003', 'Daulatpur, Khulna');
INSERT INTO CUSTOMER VALUES(1000000004, 'MR. CUSTOMER_4', 'CUSTOMER_4@gmail.com', 'CI-0000004', 'Fulbarigate, Khulna');
INSERT INTO CUSTOMER VALUES(1000000005, 'MR. CUSTOMER_5', 'CUSTOMER_5@gmail.com', 'CI-0000005', 'Rupsha, Khulna');

INSERT INTO SUPPLIER VALUES(2000000001, 'MR. SUPPLIER_1', 'SUPPLIER_1@gmail.com', 'SI-0000001', 'Khulna');
INSERT INTO SUPPLIER VALUES(2000000002, 'MR. SUPPLIER_2', 'SUPPLIER_2@gmail.com', 'SI-0000002', 'Rajshahi');
INSERT INTO SUPPLIER VALUES(2000000003, 'MR. SUPPLIER_3', 'SUPPLIER_3@gmail.com', 'SI-0000003', 'Dhaka');
INSERT INTO SUPPLIER VALUES(2000000004, 'MR. SUPPLIER_4', 'SUPPLIER_4@gmail.com', 'SI-0000004', 'Rajshahi');
INSERT INTO SUPPLIER VALUES(2000000005, 'MR. SUPPLIER_5', 'SUPPLIER_5@gmail.com', 'SI-0000005', 'Khulna');

INSERT INTO STAFF VALUES(3000000001, 'MR. STAFF_1', 'Seller', 'STAFF_1@gmail.com', 'ST-0000001', 'Boira, Khulna');
INSERT INTO STAFF VALUES(3000000002, 'MR. STAFF_2', 'Manager', 'STAFF_2@gmail.com', 'ST-0000002', 'Boira, Khulna');
INSERT INTO STAFF VALUES(3000000003, 'MR. STAFF_3', 'Security', 'STAFF_3@gmail.com', 'ST-0000003', 'Fulbarigate, Khulna');
INSERT INTO STAFF VALUES(3000000004, 'MR. STAFF_4', 'Seller', 'STAFF_4@gmail.com', 'ST-0000004', 'Rupsha, Khulna');
INSERT INTO STAFF VALUES(3000000005, 'MR. STAFF_5', 'Senior Seller', 'STAFF_5@gmail.com', 'ST-0000005', 'Fultola, Khulna');

INSERT INTO PRODUCT VALUES(4000000001, 'PRODUCT_1', 'TYPE_1', 23, 'Something about product',  2000000001);
INSERT INTO PRODUCT VALUES(4000000002, 'PRODUCT_2', 'TYPE_2', 34, 'Something about product',  2000000002);
INSERT INTO PRODUCT VALUES(4000000003, 'PRODUCT_3', 'TYPE_1', 5, 'Something about product',  2000000001);
INSERT INTO PRODUCT VALUES(4000000004, 'PRODUCT_4', 'TYPE_2', 253, 'Something about product',  2000000003);
INSERT INTO PRODUCT VALUES(4000000005, 'PRODUCT_5', 'TYPE_3', 12, 'Something about product',  2000000004);

INSERT INTO PURCHASE VALUES(5000000001, 1000000001, 4000000004, 3000000001, 2, 45, '2001-04-25');
INSERT INTO PURCHASE VALUES(5000000002, 1000000002, 4000000001, 3000000001, 3, 55, '2001-04-26');
INSERT INTO PURCHASE VALUES(5000000003, 1000000002, 4000000005, 3000000004, 2, 45, '2001-04-26');
INSERT INTO PURCHASE VALUES(5000000004, 1000000002, 4000000004, 3000000001, 5, 44, '2001-04-25');
INSERT INTO PURCHASE VALUES(5000000005, 1000000003, 4000000001, 3000000001, 5, 49, '2001-04-25');

SELECT *FROM CUSTOMER;
SELECT *FROM SUPPLIER;
SELECT *FROM STAFF;
SELECT *FROM PRODUCT;
SELECT *FROM PURCHASE;

commit;














