drop table blood_given_by_donor;
drop table blood_taken_by_patient;
drop table blood_bank;
drop table donor;
drop table patient;

create table blood_bank(
	bank_id number (4),
	bank_name varchar(10) not null,
	bank_address varchar(10) not null,
	bank_contact_no number(11) unique,
	primary key(bank_id)
);

create table donor(
	donor_id number(2),
	donor_name varchar(10) not null,
	donor_blood_group varchar(4) not null,
	donor_contact_no number(11) unique,
	donor_address varchar(10) not null,
	primary key(donor_id)
);


create table patient(
	patient_id number(2),
	patient_name varchar(10) not null,
	patient_blood_group varchar(3) not null,
	patient_disease varchar(15),
	patient_contact_no number(11) unique,
	patient_address varchar(10) not null,
	primary key(patient_id)
);


create table blood_given_by_donor(
	donor_id number(4) not null,
	bank_id number(4) not null,
	no_of_bags number(1) not null,
	date_of_blood_given date not null,
	foreign key(donor_id) REFERENCES donor(donor_id) ON DELETE CASCADE,
	foreign key(bank_id) REFERENCES blood_bank(bank_id) ON DELETE CASCADE
);

create table blood_taken_by_patient(
	patient_id number(4) not null,
	donor_id number(4) not null,
	bank_id number(4) not null,
	no_of_bags number(1) not null,
	date_of_blood_taken date not null,
	foreign key(patient_id) REFERENCES patient(patient_id) ON DELETE CASCADE,
	foreign key(donor_id) REFERENCES donor(donor_id) ON DELETE CASCADE,
	foreign key(bank_id) REFERENCES blood_bank(bank_id) ON DELETE CASCADE
);


INSERT INTO blood_bank(bank_id,bank_name,bank_address,bank_contact_no) VALUES(1001,'BloodBankA','Daulotpur',8624953);
INSERT INTO blood_bank(bank_id,bank_name,bank_address,bank_contact_no) VALUES(1002,'BloodBankB','Fulbarigte',9667821);
INSERT INTO blood_bank(bank_id,bank_name,bank_address,bank_contact_no) VALUES(1003,'BloodBankC','Khalishpur',7652589);

INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(1,'Emon','A+',0168953632,'Dhanmondi');
INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(2,'Aatik','B-',0154545532,'Uttara');
INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(3,'Setu','AB+',01921455324,'Daulotpur');
INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(4,'Rafiul','A+',01554545532,'Khalishpur');
INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(5,'Badhon','B-',0115456552,'Daulotpur');
INSERT INTO donor(donor_id,donor_name,donor_blood_group,donor_contact_no,donor_address) VALUES(6,'Jumayel','B+',0174545556,'Farmgate');

INSERT INTO patient(patient_id,patient_name,patient_blood_group,patient_disease,patient_contact_no,patient_address) VALUES(1,'Tanvir','A+','Brain Tumor',0128953332,'Khalishpur');
INSERT INTO patient(patient_id,patient_name,patient_blood_group,patient_disease,patient_contact_no,patient_address) VALUES(2,'Limon','B-','Knee Fracture',0123223432,'Uttara');



describe blood_bank;
describe donor;
describe patient;
describe blood_given_by_donor;
describe blood_taken_by_patient;


select * from blood_bank;
select * from donor;
select * from patient;
commit;